@@ -5,11 +5,10 @@ import sys
 from typing import Optional
 
 import click
-import click_log
 
 from .gitinfo import git_add, git_config_bool, git_edit, git_rm
 from .scriv import Scriv
-from .util import Version
+from .util import Version, scriv_command
 
 logger = logging.getLogger(__name__)
 
@@ -34,7 +33,7 @@ logger = logging.getLogger(__name__)
 @click.option(
     "--version", default=None, help="The version name to use for this entry."
 )
-@click_log.simple_verbosity_option()
+@scriv_command
 def collect(
     add: Optional[bool],
     edit: Optional[bool],
