@@ -98,6 +98,7 @@ def github_release(
         md = ghrel_template.render(
             body=md,
             version=version,
+            title=title,
             release=release_data,
             config=scriv.config,
         )
@@ -114,7 +115,8 @@ def github_release(
                 )
                 if dry_run:
                     logger.info(f"Would update release {version}")
-                    logger.debug(f"Body:\n{md}")
+                    logger.debug(f"Old body:\n{release['body']}")
+                    logger.debug(f"New body:\n{md}")
                 else:
                     update_release(release, release_data)
         else:
