@@ -434,7 +434,8 @@ def test_no_fragments(cli_invoke, changelog_d, temp_dir, caplog):
     (changelog_d / "README.rst").write_text("This directory has fragments")
     (temp_dir / "CHANGELOG.rst").write_text("Not much\n")
     with freezegun.freeze_time("2020-02-25T15:18:19"):
-        cli_invoke(["collect"])
+        result = cli_invoke(["collect"], expect_ok=False)
+    assert result.exit_code == 2
     changelog_text = (temp_dir / "CHANGELOG.rst").read_text()
     assert changelog_text == "Not much\n"
     assert "No changelog fragments to collect" in caplog.text
@@ -545,3 +546,36 @@ def test_duplicate_version_with_v(cli_invoke, changelog_d, temp_dir):
         str(result.exception)
         == "Entry 'v12.34.56 — 2022-09-18' already uses version '12.34.56'."
     )
+
+
+def test_unparsable_version(cli_invoke, changelog_d, temp_dir):
+    (changelog_d / "scriv.ini").write_text("[scriv]\nversion = 12.34.56\n")
+    (temp_dir / "CHANGELOG.rst").write_text(
+        textwrap.dedent(
+            """\
+            Preamble that doesn't count
+
+            v12.34.57 — 2022-09-19
+            ======================
+
+            A quick fix.
+
+            Not a version at all.
+            =====================
+
+            Good stuff.
+            """
+        ),
+        encoding="utf-8",
+    )
+
+    # Make a new fragment, and collect again without changing the version.
+    (changelog_d / "20170617_nedbat.rst").write_text(FRAG2)
+    with freezegun.freeze_time("2022-09-18T16:18:19"):
+        result = cli_invoke(["collect"], expect_ok=False)
+    assert result.exit_code == 1
+    assert str(result.exception) == (
+        "Entry 'Not a version at all.' is not a valid version! "
+        + "If scriv should ignore this heading, add "
+        + "'scriv-end-here' somewhere before it."
+    )
