@@ -85,6 +85,14 @@ class TestNewFragmentContent:
         assert "### Added\n" in content
         assert all(cat in content for cat in scriv.config.categories)
 
+    def test_final_newline_in_template_preserved(self, changelog_d):
+        (changelog_d / "new_fragment.j2").write_text("Custom template.\n")
+        scriv = Scriv(
+            config=Config(new_fragment_template="file: new_fragment.j2")
+        )
+        content = scriv.new_fragment().content
+        assert content == "Custom template.\n"
+
 
 class TestCreate:
     """
@@ -226,7 +234,7 @@ class TestCreateAdd:
     Tests of auto-adding created fragments.
     """
 
-    def test_create_add(
+    def test_create_add(  # pylint: disable=too-many-positional-arguments
         self, caplog, mocker, fake_git, cli_invoke, changelog_d
     ):
         # "scriv create --add" will invoke "git add" on the file.
@@ -261,7 +269,7 @@ class TestCreateAdd:
         )
         mock_call.assert_called_once_with(["git", "add", file_path])
 
-    def test_create_add_preference_no_add(
+    def test_create_add_preference_no_add(  # pylint: disable=too-many-positional-arguments
         self, caplog, mocker, fake_git, cli_invoke, changelog_d
     ):
         # The user can set a git configuration to default to --add, but --no-add
@@ -274,7 +282,7 @@ class TestCreateAdd:
         mock_call.assert_not_called()
         assert "Added" not in caplog.text
 
-    def test_create_add_fail(
+    def test_create_add_fail(  # pylint: disable=too-many-positional-arguments
         self, caplog, mocker, fake_git, cli_invoke, changelog_d
     ):
         # We properly handle failure to add.
