@@ -284,7 +284,8 @@ def test_dash_all_dry_run_debug(cli_invoke, scenario1, no_actions, caplog):
                 + "'v0.9a7', 'tag_name': 'v0.9a7', 'draft': False, 'prerelease': True}",
             ),
             ("scriv.ghrel", logging.INFO, "Would update release v0.9a7"),
-            ("scriv.ghrel", logging.DEBUG, "Body:\nA beginning\n"),
+            ("scriv.ghrel", logging.DEBUG, "Old body:\noriginal body"),
+            ("scriv.ghrel", logging.DEBUG, "New body:\nA beginning\n"),
             (
                 "scriv.ghrel",
                 logging.WARNING,
@@ -297,7 +298,8 @@ def test_dash_all_dry_run_debug(cli_invoke, scenario1, no_actions, caplog):
                 + "'v0.0.1', 'tag_name': 'v0.0.1', 'draft': False, 'prerelease': False}",
             ),
             ("scriv.ghrel", logging.INFO, "Would update release v0.0.1"),
-            ("scriv.ghrel", logging.DEBUG, "Body:\nVery first.\n"),
+            ("scriv.ghrel", logging.DEBUG, "Old body:\noriginal body"),
+            ("scriv.ghrel", logging.DEBUG, "New body:\nVery first.\n"),
         ],
     )
 
@@ -323,12 +325,12 @@ def test_with_template(cli_invoke, temp_dir, scenario1, mock_create_release):
     (temp_dir / "setup.cfg").write_text(
         """
         [scriv]
-        ghrel_template = |{{body}}|{{config.format}}|{{version}}
+        ghrel_template = |{{title}}|{{body}}|{{config.format}}|{{version}}|
         """
     )
     cli_invoke(["github-release"])
 
     expected = dict(V123_REL)
-    expected["body"] = "|A good release\n|rst|v1.2.3"
+    expected["body"] = "|v1.2.3 -- 2022-04-21|A good release\n|rst|v1.2.3|"
 
     assert mock_create_release.mock_calls == [call("joe/project", expected)]
