@@ -29,6 +29,9 @@ version = "1.2.3"
 
 typed_version: Final[str] = "2.3.4"
 
+thing1.attr = "3.4.5"
+thing2.attr: str = "4.5.6"
+
 # Numbers don't count.
 how_many = 123
 
@@ -215,3 +218,22 @@ def test_find_cfg_literal(name, value, temp_dir):
     with open("foo.cfg", "w", encoding="utf-8") as f:
         f.write(CFG_LITERAL)
     assert find_literal("foo.cfg", name) == value
+
+
+CABAL_LITERAL = """\
+cabal-version:      3.0
+name:               pkg
+version:            1.2.3
+"""
+
+
+@pytest.mark.parametrize(
+    "name, value",
+    [
+        ("version", "1.2.3"),
+    ],
+)
+def test_find_cabal_literal(name, value, temp_dir):
+    with open("foo.cabal", "w", encoding="utf-8") as f:
+        f.write(CABAL_LITERAL)
+    assert find_literal("foo.cabal", name) == value
